<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.System.Display

Windows Runtime (WinRT) APIs for for the `Windows.System.Display` namespace.

This package provides the `winrt.windows.system.display` module.
